@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020 Graz University of Technology.
+# Copyright (C) 2020-2021 Graz University of Technology.
 #
 # invenio-config-tugraz is free software; you can redistribute it and/or
 # modify it under the terms of the MIT License; see LICENSE file for more
@@ -172,6 +172,15 @@ SECURITY_CONFIRMABLE = False
 Instead user will get a welcome email.
 """
 
+# Flask-Security
+# =============
+# See https://pythonhosted.org/Flask-Security/configuration.html
+SECURITY_EMAIL_PLAINTEXT = True
+"""Render email content as plaintext."""
+
+SECURITY_EMAIL_HTML = False
+"""Render email content as HTML."""
+
 
 ACCOUNTS = True
 """Tells if the templates should use the accounts module.
@@ -198,16 +207,9 @@ RECAPTCHA_PRIVATE_KEY = None
 # =======
 # See:
 # https://invenio-records-permissions.readthedocs.io/en/latest/configuration.html
-#
-# Uncomment these to enable overriding Base permissions - (NOT RECOMMANDED)
-# RECORDS_PERMISSIONS_RECORD_POLICY = (
-#    'invenio_config_tugraz.base_permissions.TUGRAZPermissionPolicy'
-# )
-#
 # Uncomment these to enable overriding RDM permissions
-# RDM_RECORDS_BIBLIOGRAPHIC_SERVICE_CONFIG = (
-#     'invenio_config_tugraz.rdm_permissions.TUGRAZBibliographicRecordServiceConfig'
-# )
+# from .rdm_permissions import TUGRAZRDMRecordServiceConfig
+# RDM_RECORDS_BIBLIOGRAPHIC_SERVICE_CONFIG = TUGRAZRDMRecordServiceConfig
 """Access control configuration for records."""
 
 # invenio-rdm-records
@@ -215,9 +217,7 @@ RECAPTCHA_PRIVATE_KEY = None
 # See:
 # https://invenio-rdm-records.readthedocs.io/en/latest/configuration.html
 #
-RDM_RECORDS_USER_FIXTURE_PASSWORDS = {
-    "info@tugraz.at": None
-}
+RDM_RECORDS_USER_FIXTURE_PASSWORDS = {"info@tugraz.at": None}
 """Overrides for the user fixtures' passwords.
 The password set for a user fixture in this dictionary overrides the
 password set in the ``users.yaml`` file. This can be used to set custom
